@@ -32,6 +32,9 @@
 #include <KJobWidgets/KJobWidgets>
 #include <QtCore/QFile>
 #include <QtCore/QJsonArray>
+#include <QtCore/QDir>
+#include <QtCore/QTemporaryFile>
+#include <QIcon>
 
 Kamoso::Kamoso(WebcamControl *webcamControl)
     : m_webcamControl(webcamControl)
@@ -39,14 +42,28 @@ Kamoso::Kamoso(WebcamControl *webcamControl)
     m_recordingTime.restart();
     m_recordingTimer.setInterval(30);
 
-    connect(m_webcamControl, SIGNAL(photoTaken(QString)), this, SIGNAL(photoTaken(QString)));
+    connect(m_webcamControl, &WebcamControl::photoTaken, this, &Kamoso::photoTaken);
     connect(&m_recordingTimer, &QTimer::timeout, this, &Kamoso::recordingTimeChanged);
+
+    if (Settings::saveUrl().isLocalFile()) {
+        const QDir dir(Settings::saveUrl().toLocalFile());
+        const auto dirlist = dir.entryInfoList({"*.jpg"}, QDir::Files, QDir::SortFlag::Time);
+        if (!dirlist.isEmpty())
+            m_sampleImagePath = dirlist.first().absoluteFilePath();
+    }
+
+    if (m_sampleImagePath.isEmpty()) {
+        QTemporaryFile* temporary = new QTemporaryFile(QDir::temp().absoluteFilePath("XXXXXX-sampleimage.jpg"), this);
+        temporary->open();
+        auto sampleIcon = QIcon::fromTheme(QStringLiteral("kde"));
+        sampleIcon.pixmap(200, 200).save(temporary);
+
+        m_sampleImagePath = temporary->fileName();
+        temporary->close();
+    }
 }
 
-Kamoso::~Kamoso()
-{
-
-}
+Kamoso::~Kamoso() = default;
 
 QUrl Kamoso::fileNameSuggestion(const QUrl &saveUrl, const QString &name, const QString& extension) const
 {
@@ -67,6 +84,11 @@ const QString Kamoso::takePhoto()
     const QUrl path = fileNameSuggestion(Settings::saveUrl(), "picture", "jpg");
     m_webcamControl->takePhoto(path);
 
+    if (path.isLocalFile()) {
+        m_sampleImagePath = path.toLocalFile();
+        Q_EMIT sampleImageChanged(m_sampleImagePath);
+    }
+
     return path.toDisplayString();
 }
 
@@ -91,7 +113,7 @@ void Kamoso::setRecording(bool recording)
         KJob *job = KIO::move(QUrl::fromLocalFile(m_webcamControl->stopRecording()), path);
         job->start();
 
-        m_webcamControl->play(DeviceManager::self()->playingDevice());
+        m_webcamControl->playDevice(DeviceManager::self()->playingDevice());
         m_recordingTimer.stop();
     }
 
